@@ -57,6 +57,8 @@ class RepoEvents(Document):
     total = IntField(default=0)
     commit_files = ListField()
     
+    # KPIs
+    total_kpis = FloatField(default=0.0)
     velocity_kpi = EmbeddedDocumentField(VelocityKPI)
     issues_total = EmbeddedDocumentField(IssuesTotal)
 
@@ -83,11 +85,8 @@ class LinterScanEvent(EmbeddedDocument):
     linter_name = StringField()
     file_path = StringField()
 
-    devops_warnings = IntField()
-    devops_errors = IntField()
-
-    code_warnings = IntField()
-    code_errors = IntField()
+    warnings = IntField()
+    errors = IntField()
 
     linter_output = StringField()
 
@@ -230,3 +229,7 @@ class JiraIssue(Document):
     updated = DateTimeField()
     work_begin_date = DateTimeField()
     work_completed_date = DateTimeField()
+
+
+class SkippedRepo(Document):
+    repo_name = StringField(max_length=120, primary_key=True, required=True)
\ No newline at end of file
